==> commons-compress-1.18.1.jar: module-info.java <==
/* synthetic */ module org.apache.commons.compress {
    exports org.apache.commons.compress;
    exports org.apache.commons.compress.archivers;
    exports org.apache.commons.compress.archivers.ar;
    exports org.apache.commons.compress.archivers.arj;
    exports org.apache.commons.compress.archivers.cpio;
    exports org.apache.commons.compress.archivers.dump;
    exports org.apache.commons.compress.archivers.examples;
    exports org.apache.commons.compress.archivers.jar;
    exports org.apache.commons.compress.archivers.sevenz;
    exports org.apache.commons.compress.archivers.tar;
    exports org.apache.commons.compress.archivers.zip;
    exports org.apache.commons.compress.changes;
    exports org.apache.commons.compress.compressors;
    exports org.apache.commons.compress.compressors.brotli;
    exports org.apache.commons.compress.compressors.bzip2;
    exports org.apache.commons.compress.compressors.deflate;
    exports org.apache.commons.compress.compressors.deflate64;
    exports org.apache.commons.compress.compressors.gzip;
    exports org.apache.commons.compress.compressors.lz4;
    exports org.apache.commons.compress.compressors.lz77support;
    exports org.apache.commons.compress.compressors.lzma;
    exports org.apache.commons.compress.compressors.lzw;
    exports org.apache.commons.compress.compressors.pack200;
    exports org.apache.commons.compress.compressors.snappy;
    exports org.apache.commons.compress.compressors.xz;
    exports org.apache.commons.compress.compressors.z;
    exports org.apache.commons.compress.compressors.zstandard;
    exports org.apache.commons.compress.parallel;
    exports org.apache.commons.compress.utils;
    exports org.tukaani.xz;
    exports org.tukaani.xz.check;
    exports org.tukaani.xz.common;
    exports org.tukaani.xz.delta;
    exports org.tukaani.xz.index;
    exports org.tukaani.xz.lz;
    exports org.tukaani.xz.lzma;
    exports org.tukaani.xz.rangecoder;
    exports org.tukaani.xz.simple;

}

==> commons-compress-1.21.0.jar: module-info.java <==
/* synthetic */ module org.apache.commons.compress {
    requires org.tukaani.xz;
    requires java.desktop;

    exports org.apache.commons.compress;
    exports org.apache.commons.compress.archivers;
    exports org.apache.commons.compress.archivers.ar;
    exports org.apache.commons.compress.archivers.arj;
    exports org.apache.commons.compress.archivers.cpio;
    exports org.apache.commons.compress.archivers.dump;
    exports org.apache.commons.compress.archivers.examples;
    exports org.apache.commons.compress.archivers.jar;
    exports org.apache.commons.compress.archivers.sevenz;
    exports org.apache.commons.compress.archivers.tar;
    exports org.apache.commons.compress.archivers.zip;
    exports org.apache.commons.compress.changes;
    exports org.apache.commons.compress.compressors;
    exports org.apache.commons.compress.compressors.brotli;
    exports org.apache.commons.compress.compressors.bzip2;
    exports org.apache.commons.compress.compressors.deflate;
    exports org.apache.commons.compress.compressors.deflate64;
    exports org.apache.commons.compress.compressors.gzip;
    exports org.apache.commons.compress.compressors.lz4;
    exports org.apache.commons.compress.compressors.lz77support;
    exports org.apache.commons.compress.compressors.lzma;
    exports org.apache.commons.compress.compressors.lzw;
    exports org.apache.commons.compress.compressors.pack200;
    exports org.apache.commons.compress.compressors.snappy;
    exports org.apache.commons.compress.compressors.xz;
    exports org.apache.commons.compress.compressors.z;
    exports org.apache.commons.compress.compressors.zstandard;
    exports org.apache.commons.compress.harmony.archive.internal.nls;
    exports org.apache.commons.compress.harmony.unpack200;
    exports org.apache.commons.compress.harmony.unpack200.bytecode;
    exports org.apache.commons.compress.harmony.unpack200.bytecode.forms;
    exports org.apache.commons.compress.java.util.jar;
    exports org.apache.commons.compress.parallel;
    exports org.apache.commons.compress.utils;

}
